@@ -237,7 +237,8 @@ class Client:
         """
         upload_infos = self.upload_infos(_file_hash256(file_path), project_id=project_id)
         if upload_infos.get("status") == "available":
-            raise AlreadyUploaded()
+            return upload_infos.get("id")
+            #raise AlreadyUploaded()
 
         chunked_upload = _ChunksUploader(
             file_path,
